@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """This module contains a set of functions to handle python protocols for nodes
 where it makes sense.
@@ -12,9 +12,9 @@ import collections
 import itertools
 import operator as operator_mod
 from collections.abc import Callable, Generator, Iterator, Sequence
-from typing import Any, TypeVar
+from typing import TYPE_CHECKING, Any, TypeVar
 
-from astroid import arguments, bases, decorators, helpers, nodes, util
+from astroid import bases, decorators, nodes, util
 from astroid.const import Context
 from astroid.context import InferenceContext, copy_context
 from astroid.exceptions import (
@@ -31,51 +31,11 @@ from astroid.typing import (
     SuccessfulInferenceResult,
 )
 
-raw_building = util.lazy_import("raw_building")
-objects = util.lazy_import("objects")
-
-
-_TupleListNodeT = TypeVar("_TupleListNodeT", nodes.Tuple, nodes.List)
-
-
-def _reflected_name(name) -> str:
-    return "__r" + name[2:]
-
-
-def _augmented_name(name) -> str:
-    return "__i" + name[2:]
-
+if TYPE_CHECKING:
+    _TupleListNodeT = TypeVar("_TupleListNodeT", nodes.Tuple, nodes.List)
 
 _CONTEXTLIB_MGR = "contextlib.contextmanager"
-BIN_OP_METHOD = {
-    "+": "__add__",
-    "-": "__sub__",
-    "/": "__truediv__",
-    "//": "__floordiv__",
-    "*": "__mul__",
-    "**": "__pow__",
-    "%": "__mod__",
-    "&": "__and__",
-    "|": "__or__",
-    "^": "__xor__",
-    "<<": "__lshift__",
-    ">>": "__rshift__",
-    "@": "__matmul__",
-}
 
-REFLECTED_BIN_OP_METHOD = {
-    key: _reflected_name(value) for (key, value) in BIN_OP_METHOD.items()
-}
-AUGMENTED_OP_METHOD = {
-    key + "=": _augmented_name(value) for (key, value) in BIN_OP_METHOD.items()
-}
-
-UNARY_OP_METHOD = {
-    "+": "__pos__",
-    "-": "__neg__",
-    "~": "__invert__",
-    "not": None,  # XXX not '__nonzero__'
-}
 _UNARY_OPERATORS: dict[str, Callable[[Any], Any]] = {
     "+": operator_mod.pos,
     "-": operator_mod.neg,
@@ -97,11 +57,25 @@ def _infer_unary_op(obj: Any, op: str) -> ConstFactoryResult:
     return nodes.const_factory(value)
 
 
-nodes.Tuple.infer_unary_op = lambda self, op: _infer_unary_op(tuple(self.elts), op)
-nodes.List.infer_unary_op = lambda self, op: _infer_unary_op(self.elts, op)
-nodes.Set.infer_unary_op = lambda self, op: _infer_unary_op(set(self.elts), op)
-nodes.Const.infer_unary_op = lambda self, op: _infer_unary_op(self.value, op)
-nodes.Dict.infer_unary_op = lambda self, op: _infer_unary_op(dict(self.items), op)
+def tuple_infer_unary_op(self, op):
+    return _infer_unary_op(tuple(self.elts), op)
+
+
+def list_infer_unary_op(self, op):
+    return _infer_unary_op(self.elts, op)
+
+
+def set_infer_unary_op(self, op):
+    return _infer_unary_op(set(self.elts), op)
+
+
+def const_infer_unary_op(self, op):
+    return _infer_unary_op(self.value, op)
+
+
+def dict_infer_unary_op(self, op):
+    return _infer_unary_op(dict(self.items), op)
+
 
 # Binary operations
 
@@ -161,22 +135,22 @@ def const_infer_binary_op(
         yield not_implemented
 
 
-nodes.Const.infer_binary_op = const_infer_binary_op
-
-
 def _multiply_seq_by_int(
     self: _TupleListNodeT,
     opnode: nodes.AugAssign | nodes.BinOp,
-    other: nodes.Const,
+    value: int,
     context: InferenceContext,
 ) -> _TupleListNodeT:
     node = self.__class__(parent=opnode)
+    if value > 1e8:
+        node.elts = [util.Uninferable]
+        return node
     filtered_elts = (
-        helpers.safe_infer(elt, context) or util.Uninferable
+        util.safe_infer(elt, context) or util.Uninferable
         for elt in self.elts
         if not isinstance(elt, util.UninferableBase)
     )
-    node.elts = list(filtered_elts) * other.value
+    node.elts = list(filtered_elts) * value
     return node
 
 
@@ -209,6 +183,8 @@ def tl_infer_binary_op(
     or list. This refers to the left-hand side of the operation, so:
     'tuple() + 1' or '[] + A()'
     """
+    from astroid import helpers  # pylint: disable=import-outside-toplevel
+
     # For tuples and list the boundnode is no longer the tuple or list instance
     context.boundnode = None
     not_implemented = nodes.Const(NotImplemented)
@@ -225,25 +201,24 @@ def tl_infer_binary_op(
         if not isinstance(other.value, int):
             yield not_implemented
             return
-        yield _multiply_seq_by_int(self, opnode, other, context)
+        yield _multiply_seq_by_int(self, opnode, other.value, context)
     elif isinstance(other, bases.Instance) and operator == "*":
         # Verify if the instance supports __index__.
         as_index = helpers.class_instance_as_index(other)
         if not as_index:
             yield util.Uninferable
+        elif not isinstance(as_index.value, int):  # pragma: no cover
+            # already checked by class_instance_as_index() but faster than casting
+            raise AssertionError("Please open a bug report.")
         else:
-            yield _multiply_seq_by_int(self, opnode, as_index, context)
+            yield _multiply_seq_by_int(self, opnode, as_index.value, context)
     else:
         yield not_implemented
 
 
-nodes.Tuple.infer_binary_op = tl_infer_binary_op
-nodes.List.infer_binary_op = tl_infer_binary_op
-
-
 @decorators.yes_if_nothing_inferred
 def instance_class_infer_binary_op(
-    self: bases.Instance | nodes.ClassDef,
+    self: nodes.ClassDef,
     opnode: nodes.AugAssign | nodes.BinOp,
     operator: str,
     other: InferenceResult,
@@ -253,12 +228,8 @@ def instance_class_infer_binary_op(
     return method.infer_call_result(self, context)
 
 
-bases.Instance.infer_binary_op = instance_class_infer_binary_op
-nodes.ClassDef.infer_binary_op = instance_class_infer_binary_op
-
-
 # assignment ##################################################################
-
+# pylint: disable-next=pointless-string-statement
 """The assigned_stmts method is responsible to return the assigned statement
 (e.g. not inferred) according to the assignment type.
 
@@ -341,10 +312,6 @@ def for_assigned_stmts(
     }
 
 
-nodes.For.assigned_stmts = for_assigned_stmts
-nodes.Comprehension.assigned_stmts = for_assigned_stmts
-
-
 def sequence_assigned_stmts(
     self: nodes.Tuple | nodes.List,
     node: node_classes.AssignedStmtsPossibleNode = None,
@@ -369,10 +336,6 @@ def sequence_assigned_stmts(
     )
 
 
-nodes.Tuple.assigned_stmts = sequence_assigned_stmts
-nodes.List.assigned_stmts = sequence_assigned_stmts
-
-
 def assend_assigned_stmts(
     self: nodes.AssignName | nodes.AssignAttr,
     node: node_classes.AssignedStmtsPossibleNode = None,
@@ -382,23 +345,22 @@ def assend_assigned_stmts(
     return self.parent.assigned_stmts(node=self, context=context)
 
 
-nodes.AssignName.assigned_stmts = assend_assigned_stmts
-nodes.AssignAttr.assigned_stmts = assend_assigned_stmts
-
-
 def _arguments_infer_argname(
     self, name: str | None, context: InferenceContext
 ) -> Generator[InferenceResult, None, None]:
     # arguments information may be missing, in which case we can't do anything
     # more
-    if not (self.arguments or self.vararg or self.kwarg):
+    from astroid import arguments  # pylint: disable=import-outside-toplevel
+
+    if not self.arguments:
         yield util.Uninferable
         return
 
+    args = [arg for arg in self.arguments if arg.name not in [self.vararg, self.kwarg]]
     functype = self.parent.type
     # first argument of instance/class method
     if (
-        self.arguments
+        args
         and getattr(self.arguments[0], "name", None) == name
         and functype != "staticmethod"
     ):
@@ -427,7 +389,7 @@ def _arguments_infer_argname(
     if name == self.vararg:
         vararg = nodes.const_factory(())
         vararg.parent = self
-        if not self.arguments and self.parent.name == "__init__":
+        if not args and self.parent.name == "__init__":
             cls = self.parent.parent.scope()
             vararg.elts = [cls.instantiate_class()]
         yield vararg
@@ -453,11 +415,13 @@ def arguments_assigned_stmts(
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
 ) -> Any:
+    from astroid import arguments  # pylint: disable=import-outside-toplevel
+
     try:
         node_name = node.name  # type: ignore[union-attr]
     except AttributeError:
         # Added to handle edge cases where node.name is not defined.
-        # https://github.com/PyCQA/astroid/pull/1644#discussion_r901545816
+        # https://github.com/pylint-dev/astroid/pull/1644#discussion_r901545816
         node_name = None  # pragma: no cover
 
     if context and context.callcontext:
@@ -466,7 +430,7 @@ def arguments_assigned_stmts(
             callee = callee._proxied
     else:
         return _arguments_infer_argname(self, node_name, context)
-    if node and getattr(callee, "name", None) == node.frame(future=True).name:
+    if node and getattr(callee, "name", None) == node.frame().name:
         # reset call context/name
         callcontext = context.callcontext
         context = copy_context(context)
@@ -476,12 +440,9 @@ def arguments_assigned_stmts(
     return _arguments_infer_argname(self, node_name, context)
 
 
-nodes.Arguments.assigned_stmts = arguments_assigned_stmts
-
-
 @decorators.raise_if_nothing_inferred
 def assign_assigned_stmts(
-    self: nodes.AugAssign | nodes.Assign | nodes.AnnAssign,
+    self: nodes.AugAssign | nodes.Assign | nodes.AnnAssign | nodes.TypeAlias,
     node: node_classes.AssignedStmtsPossibleNode = None,
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
@@ -514,11 +475,6 @@ def assign_annassigned_stmts(
             yield inferred
 
 
-nodes.Assign.assigned_stmts = assign_assigned_stmts
-nodes.AnnAssign.assigned_stmts = assign_annassigned_stmts
-nodes.AugAssign.assigned_stmts = assign_assigned_stmts
-
-
 def _resolve_assignment_parts(parts, assign_path, context):
     """Recursive function to resolve multiple assignments."""
     assign_path = assign_path[:]
@@ -566,6 +522,8 @@ def excepthandler_assigned_stmts(
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
 ) -> Any:
+    from astroid import objects  # pylint: disable=import-outside-toplevel
+
     for assigned in node_classes.unpack_infer(self.type):
         if isinstance(assigned, nodes.ClassDef):
             assigned = objects.ExceptionInstance(assigned)
@@ -579,9 +537,6 @@ def excepthandler_assigned_stmts(
     }
 
 
-nodes.ExceptHandler.assigned_stmts = excepthandler_assigned_stmts
-
-
 def _infer_context_manager(self, mgr, context):
     try:
         inferred = next(mgr.infer(context=context))
@@ -700,9 +655,6 @@ def with_assigned_stmts(
     }
 
 
-nodes.With.assigned_stmts = with_assigned_stmts
-
-
 @decorators.raise_if_nothing_inferred
 def named_expr_assigned_stmts(
     self: nodes.NamedExpr,
@@ -722,9 +674,6 @@ def named_expr_assigned_stmts(
         )
 
 
-nodes.NamedExpr.assigned_stmts = named_expr_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def starred_assigned_stmts(  # noqa: C901
     self: nodes.Starred,
@@ -759,7 +708,7 @@ def starred_assigned_stmts(  # noqa: C901
                 lookups.append((index, len(element.itered())))
                 _determine_starred_iteration_lookups(starred, element, lookups)
 
-    stmt = self.statement(future=True)
+    stmt = self.statement()
     if not isinstance(stmt, (nodes.Assign, nodes.For)):
         raise InferenceError(
             "Statement {stmt!r} enclosing {node!r} must be an Assign or For node.",
@@ -922,9 +871,6 @@ def starred_assigned_stmts(  # noqa: C901
         yield util.Uninferable
 
 
-nodes.Starred.assigned_stmts = starred_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_mapping_assigned_stmts(
     self: nodes.MatchMapping,
@@ -939,9 +885,6 @@ def match_mapping_assigned_stmts(
     yield
 
 
-nodes.MatchMapping.assigned_stmts = match_mapping_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_star_assigned_stmts(
     self: nodes.MatchStar,
@@ -956,9 +899,6 @@ def match_star_assigned_stmts(
     yield
 
 
-nodes.MatchStar.assigned_stmts = match_star_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_as_assigned_stmts(
     self: nodes.MatchAs,
@@ -977,4 +917,15 @@ def match_as_assigned_stmts(
         yield self.parent.parent.subject
 
 
-nodes.MatchAs.assigned_stmts = match_as_assigned_stmts
+@decorators.yes_if_nothing_inferred
+def generic_type_assigned_stmts(
+    self: nodes.TypeVar | nodes.TypeVarTuple | nodes.ParamSpec,
+    node: nodes.AssignName,
+    context: InferenceContext | None = None,
+    assign_path: None = None,
+) -> Generator[nodes.NodeNG, None, None]:
+    """Return empty generator (return -> raises StopIteration) so inferred value
+    is Uninferable.
+    """
+    return
+    yield
